const std = @import("std");

pub fn build(b: *std.Build) void {
    const zg = b.dependency("zg", .{});
    const target = b.standardTargetOptions(.{});

    const optimize = b.standardOptimizeOption(.{});

    const exe = b.addExecutable(.{
        .name = "proxy-print",
        .root_source_file = b.path("src/print.zig"),
        .target = target,
        .optimize = optimize,
    });

    exe.addCSourceFiles(.{
        .files = &.{"pdfgen.c"},
        .root = b.path("src/"),
    });
    exe.addIncludePath(b.path("include"));
    exe.linkLibC();
    exe.root_module.addImport("grapheme", zg.module("grapheme"));
    exe.root_module.addImport("DisplayWidth", zg.module("DisplayWidth"));
    const clap = b.dependency("clap", .{});
    exe.root_module.addImport("clap", clap.module("clap"));

    b.installArtifact(exe);

    const run_cmd = b.addRunArtifact(exe);

    run_cmd.step.dependOn(b.getInstallStep());

    if (b.args) |args| {
        run_cmd.addArgs(args);
    }

    const run_step = b.step("run", "Run the app");
    run_step.dependOn(&run_cmd.step);

    const exe_unit_tests = b.addTest(.{
        .root_source_file = b.path("src/print.zig"),
        .target = target,
        .optimize = optimize,
    });

    const run_exe_unit_tests = b.addRunArtifact(exe_unit_tests);

    const test_step = b.step("test", "Run unit tests");
    test_step.dependOn(&run_exe_unit_tests.step);
}
